SystemOrganization addCategory: #GaruthaContactBook!

TestCase subclass: #ContactBookTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!ContactBookTest methodsFor: 'tests' stamp: 'GabrielGermain 10/17/2018 23:53'!
testRemoveContact
	| contact book |
	contact := Contact newNamed: 'Gab Ger' email: 'gg@gmail.com'.
	book := ContactBook new.
	book addContact: contact.
	self assert: (book contacts includes: contact ).
	book removeContact: contact.
	self assert: (book contacts isEmpty)! !

!ContactBookTest methodsFor: 'tests' stamp: 'GabrielGermain 10/17/2018 23:54'!
testRemoveUnkownContact
	| contact book |
	contact := Contact newNamed: 'Gab Ger' email: 'gg@gmail.com'.
	book := ContactBook new.
	book removeContact: contact.
	self assert: (book contacts isEmpty)! !

TestCase subclass: #ContactTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!ContactTest methodsFor: 'tests' stamp: 'GabrielGermain 10/17/2018 23:01'!
testCreation
	| contact |
	contact := Contact newNamed: 'Marcus Denker' email: 'marcus.denker@inria.fr'.
	self assert: contact fullname equals: 'Marcus Denker'.
	self assert: contact email equals: 'marcus.denker@inria.fr'! !

!ContactTest methodsFor: 'tests' stamp: 'GabrielGermain 10/17/2018 23:58'!
testPrintOn
	| contact |
	contact := Contact newNamed: 'Marcus Denker' email: 'marcus.denker@inria.fr'.
	self assert: contact asString equals: 'Marcus Denker <marcus.denker@inria.fr>'.! !

WAComponent subclass: #WAContact
	instanceVariableNames: 'contact'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!WAContact commentStamp: 'GabrielGermain 10/28/2018 18:58' prior: 0!
I'm a contact component.!

!WAContact class methodsFor: 'initialization' stamp: 'GabrielGermain 10/28/2018 18:58'!
editContact: aContact
	^ self new
		setContact: aContact;
		yourself! !

!WAContact methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 18:59'!
contact
	^ contact! !

!WAContact methodsFor: 'class initialization' stamp: 'GabrielGermain 10/28/2018 18:59'!
initialize
	super initialize.
	contact := Contact new! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:04'!
renderButtonsOn: html
	html
		tbsFormGroup: [ html
				tbsButtonGroup: [ self
						renderSubmitButtonOn: html;
						renderCancelButtonOn: html ] ]! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:04'!
renderCancelButtonOn: html
	html tbsButton
		beDanger;
		cancelCallback: [ self answer: nil ];
		with: 'Cancel'! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:04'!
renderContentOn: html
	html
		tbsContainer: [ html heading with: 'Contact Editing'.
			html tbsForm
				with: [ self renderFieldsOn: html.
					self renderButtonsOn: html ] ]! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:02'!
renderEmailFieldOn: html
	html
		tbsFormGroup: [ html label: 'Email'.
			html emailInput
				tbsFormControl;
				placeholder: 'your@email.eu';
				callback: [ :email | self contact email: email address ];
				value: (self contact email ifNil: '') ]! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:00'!
renderFieldsOn: html
	self renderFullnameFieldOn: html.
	self renderEmailFieldOn: html! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:01'!
renderFullnameFieldOn: html
	html
		tbsFormGroup: [ html label: 'Fullname'.
			html textInput
				tbsFormControl;
				placeholder: 'fullname';
				callback: [ :value | self contact fullname: value ];
				value: (self contact fullname ifNil: '') ]! !

!WAContact methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:04'!
renderSubmitButtonOn: html
	html tbsSubmitButton
		beSuccess;
		bePrimary;
		callback: [ self answer: self contact ];
		with: 'Save'! !

!WAContact methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 18:59'!
setContact: aContact
	contact := aContact! !

WAComponent subclass: #WAContactBook
	instanceVariableNames: 'contactBook'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!WAContactBook commentStamp: 'GabrielGermain 10/27/2018 21:59' prior: 0!
I'm a ContactBook component.!

!WAContactBook class methodsFor: 'class initialization' stamp: 'GabrielGermain 10/28/2018 18:46'!
initialize
	(WAAdmin register: self asApplicationAt: 'contacts')
		addLibrary: JQDeploymentLibrary;
		addLibrary: TBSDeploymentLibrary! !

WAContactBook initialize!

!WAContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 19:08'!
addContact
	(self call: WAContact new) ifNotNil: [ :contact | contactBook addContact: contact ]! !

!WAContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 18:39'!
contactBook
	^ contactBook ifNil: [ contactBook := ContactBook createDefault ]! !

!WAContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 18:38'!
contacts
	^ self contactBook contacts! !

!WAContactBook methodsFor: 'iterating' stamp: 'GabrielGermain 10/28/2018 18:39'!
contactsDo: aBlock
	self contacts do: aBlock! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:06'!
renderButtonsForContact: aContact on: html
	html
		tbsButtonGroup: [ self
				renderEditButtonForContact: aContact on: html;
				renderRemoveButtonForContact: aContact on: html ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:06'!
renderContact: aContact on: html
	html
		tableRow: [ html
				tableData: aContact fullname;
				tableData: aContact email;
				tableData: [ self renderPhotoOf: aContact on: html ];
				tableData: [ self renderButtonsForContact: aContact on: html ] ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 18:51'!
renderContactsOn: html
	html
		tbsTable: [ html
				tableHead: [ html
						tableHeading: 'Name';
						tableHeading: 'Email';
						tableHeading: 'Photo' ].
			self contactsDo: [ :contact | self renderContact: contact on: html ] ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:08'!
renderContentOn: html
	"Main entry point of the view. Render both a title and the list of contacts."

	html
		tbsContainer: [ html heading
				level: 1;
				with: 'My Contact Book'.
			html tbsForm: [ self renderContactsOn: html. self renderGlobalButtonsOn: html] ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:06'!
renderEditButtonForContact: aContact on: html
	html tbsButton
		beSuccess;
		callback: [ self call: (WAContact editContact: aContact) ];
		with: 'Edit'! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 19:08'!
renderGlobalButtonsOn: html
	html
		tbsButtonGroup: [ html tbsButton
				beSuccess;
				callback: [ self addContact ];
				with: 'New contact' ]! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 18:52'!
renderPhotoOf: aContact on: html
	html image url: aContact gravatarUrl! !

!WAContactBook methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 18:54'!
renderRemoveButtonForContact: aContact on: html
	html tbsButton
		beDanger;
		callback: [ self contactBook removeContact: aContact ];
		with: 'Remove'! !

!WAContactBook methodsFor: 'updating' stamp: 'GabrielGermain 10/28/2018 18:38'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot title: 'Contact Book'! !

Object subclass: #Contact
	instanceVariableNames: 'fullname email'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!Contact commentStamp: 'GabrielGermain 10/17/2018 23:02' prior: 0!
I represent a person with a name and an email address. I'm usually
part of a contact book.!

!Contact class methodsFor: 'instance creation' stamp: 'GabrielGermain 10/17/2018 23:01'!
newNamed: aNameString email: anEmailString
	^ self new
		fullname: aNameString;
		email: anEmailString;
		yourself! !

!Contact methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:00'!
email
	^ email! !

!Contact methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:00'!
email: aString 
	email := aString! !

!Contact methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:00'!
fullname
	^ fullname! !

!Contact methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 22:59'!
fullname: aString 
	fullname := aString! !

!Contact methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 18:51'!
gravatarUrl
	^ 'http://www.gravatar.com/avatar/' , (MD5 hashMessage: email trimBoth asLowercase) hex , '.jpg'! !

!Contact methodsFor: 'printing' stamp: 'GabrielGermain 10/17/2018 23:28'!
printOn: sStream
	sStream
		<< self fullname;
		<< ' <';
		<< self email;
		<< '>'! !

Object subclass: #ContactBook
	instanceVariableNames: 'contacts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaContactBook'!

!ContactBook commentStamp: 'GabrielGermain 10/17/2018 23:33' prior: 0!
I'm a ContactBook.!

!ContactBook class methodsFor: 'default' stamp: 'GabrielGermain 10/27/2018 21:55'!
createDefault
	^ self new
		addContact: (Contact newNamed: 'Damien Cassou' email: 'damien@cassou.me');
		addContact: (Contact newNamed: 'Marcus Denker' email: 'marcus.denker@inria.fr');
		addContact: (Contact newNamed: 'Tudor Girba' email: 'tudor@tudorgirba.com');
		addContact: (Contact newNamed: 'Clara Allende' email: 'clari.allende@gmail.com');
		yourself! !

!ContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:35'!
addContact: aContact
	self contacts add: aContact! !

!ContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:34'!
contacts
	^ contacts ifNil: [ contacts := OrderedCollection new ]! !

!ContactBook methodsFor: 'accessing' stamp: 'GabrielGermain 10/17/2018 23:56'!
removeContact: aContact
	self contacts remove: aContact ifAbsent: [  ]! !

WAContactBook initialize!
